@@ -2,9 +2,9 @@
 
 #include "../helpers/AnimatedVariable.hpp"
 #include <string>
-#include "../defines.hpp"
 #include "DesktopTypes.hpp"
 #include "../helpers/MiscFunctions.hpp"
+#include "../helpers/signal/Signal.hpp"
 
 enum eFullscreenMode : int8_t {
     FSMODE_NONE       = 0,
@@ -22,61 +22,55 @@ class CWorkspace {
     CWorkspace(WORKSPACEID id, PHLMONITOR monitor, std::string name, bool special = false, bool isEmpty = true);
     ~CWorkspace();
 
+    WP<CWorkspace> m_self;
+
     // Workspaces ID-based have IDs > 0
     // and workspaces name-based have IDs starting with -1337
-    WORKSPACEID   m_iID    = WORKSPACE_INVALID;
-    std::string   m_szName = "";
-    PHLMONITORREF m_pMonitor;
-    // Previous workspace ID and name is stored during a workspace change, allowing travel
-    // to the previous workspace.
-    SWorkspaceIDName m_sPrevWorkspace, m_sPrevWorkspacePerMonitor;
+    WORKSPACEID     m_id   = WORKSPACE_INVALID;
+    std::string     m_name = "";
+    PHLMONITORREF   m_monitor;
 
-    bool             m_bHasFullscreenWindow = false;
-    eFullscreenMode  m_efFullscreenMode     = FSMODE_NONE;
+    bool            m_hasFullscreenWindow = false;
+    eFullscreenMode m_fullscreenMode      = FSMODE_NONE;
 
-    wl_array         m_wlrCoordinateArr;
+    wl_array        m_wlrCoordinateArr;
 
     // for animations
-    CAnimatedVariable<Vector2D> m_vRenderOffset;
-    CAnimatedVariable<float>    m_fAlpha;
-    bool                        m_bForceRendering = false;
+    PHLANIMVAR<Vector2D> m_renderOffset;
+    PHLANIMVAR<float>    m_alpha;
+    bool                 m_forceRendering = false;
 
     // allows damage to propagate.
-    bool m_bVisible = false;
+    bool m_visible = false;
 
     // "scratchpad"
-    bool m_bIsSpecialWorkspace = false;
+    bool m_isSpecialWorkspace = false;
 
     // last window
-    PHLWINDOWREF m_pLastFocusedWindow;
+    PHLWINDOWREF m_lastFocusedWindow;
 
     // user-set
-    bool m_bDefaultFloating = false;
-    bool m_bDefaultPseudo   = false;
+    bool m_defaultFloating = false;
+    bool m_defaultPseudo   = false;
 
     // last monitor (used on reconnect)
-    std::string m_szLastMonitor = "";
+    std::string m_lastMonitor = "";
 
-    bool        m_bWasCreatedEmpty = true;
-
-    bool        m_bPersistent = false;
+    bool        m_wasCreatedEmpty = true;
 
     // Inert: destroyed and invalid. If this is true, release the ptr you have.
     bool             inert();
-    void             startAnim(bool in, bool left, bool instant = false);
-    void             setActive(bool on);
-    void             moveToMonitor(const MONITORID&);
     MONITORID        monitorID();
     PHLWINDOW        getLastFocusedWindow();
     void             rememberPrevWorkspace(const PHLWORKSPACE& prevWorkspace);
     std::string      getConfigName();
     bool             matchesStaticSelector(const std::string& selector);
     void             markInert();
-    SWorkspaceIDName getPrevWorkspaceIDName(bool perMonitor) const;
+    SWorkspaceIDName getPrevWorkspaceIDName() const;
     void             updateWindowDecos();
     void             updateWindowData();
-    int              getWindows(std::optional<bool> onlyTiled = {}, std::optional<bool> onlyVisible = {});
-    int              getGroups(std::optional<bool> onlyTiled = {}, std::optional<bool> onlyVisible = {});
+    int              getWindows(std::optional<bool> onlyTiled = {}, std::optional<bool> onlyPinned = {}, std::optional<bool> onlyVisible = {});
+    int              getGroups(std::optional<bool> onlyTiled = {}, std::optional<bool> onlyPinned = {}, std::optional<bool> onlyVisible = {});
     bool             hasUrgentWindow();
     PHLWINDOW        getFirstWindow();
     PHLWINDOW        getTopLeftWindow();
@@ -86,13 +80,27 @@ class CWorkspace {
     void             rename(const std::string& name = "");
     void             forceReportSizesToWindows();
     void             updateWindows();
+    void             setPersistent(bool persistent);
+    bool             isPersistent();
+
+    struct {
+        CSignalT<> destroy;
+        CSignalT<> renamed;
+        CSignalT<> monitorChanged;
+        CSignalT<> activeChanged;
+    } m_events;
 
   private:
-    void                 init(PHLWORKSPACE self);
+    void init(PHLWORKSPACE self);
+    // Previous workspace ID and name is stored during a workspace change, allowing travel
+    // to the previous workspace.
+    SWorkspaceIDName     m_prevWorkspace;
 
-    SP<HOOK_CALLBACK_FN> m_pFocusedWindowHook;
-    bool                 m_bInert = true;
-    WP<CWorkspace>       m_pSelf;
+    SP<HOOK_CALLBACK_FN> m_focusedWindowHook;
+    bool                 m_inert = true;
+
+    SP<CWorkspace>       m_selfPersistent; // for persistent workspaces.
+    bool                 m_persistent = false;
 };
 
 inline bool valid(const PHLWORKSPACE& ref) {
