@@ -18,18 +18,18 @@ class CGammaControl {
     PHLMONITOR getMonitor();
 
   private:
-    SP<CZwlrGammaControlV1> resource;
-    PHLMONITORREF           pMonitor;
-    size_t                  gammaSize     = 0;
-    bool                    gammaTableSet = false;
-    std::vector<uint16_t>   gammaTable; // [r,g,b]+
+    SP<CZwlrGammaControlV1> m_resource;
+    PHLMONITORREF           m_monitor;
+    size_t                  m_gammaSize     = 0;
+    bool                    m_gammaTableSet = false;
+    std::vector<uint16_t>   m_gammaTable; // [r,g,b]+
 
     void                    onMonitorDestroy();
 
     struct {
         CHyprSignalListener monitorDisconnect;
         CHyprSignalListener monitorDestroy;
-    } listeners;
+    } m_listeners;
 };
 
 class CGammaControlProtocol : public IWaylandProtocol {
@@ -46,8 +46,8 @@ class CGammaControlProtocol : public IWaylandProtocol {
     void onGetGammaControl(CZwlrGammaControlManagerV1* pMgr, uint32_t id, wl_resource* output);
 
     //
-    std::vector<UP<CZwlrGammaControlManagerV1>> m_vManagers;
-    std::vector<UP<CGammaControl>>              m_vGammaControllers;
+    std::vector<UP<CZwlrGammaControlManagerV1>> m_managers;
+    std::vector<UP<CGammaControl>>              m_gammaControllers;
 
     friend class CGammaControl;
 };
