@@ -3,6 +3,8 @@
 #include <vector>
 #include <cstdint>
 #include "WaylandProtocol.hpp"
+#include "../devices/IKeyboard.hpp"
+#include "../devices/VirtualKeyboard.hpp"
 #include "virtual-keyboard-unstable-v1.hpp"
 #include "../helpers/signal/Signal.hpp"
 #include <hyprutils/os/FileDescriptor.hpp>
@@ -13,25 +15,26 @@ class CVirtualKeyboardV1Resource {
     ~CVirtualKeyboardV1Resource();
 
     struct {
-        CSignal destroy;
-        CSignal key;
-        CSignal modifiers;
-        CSignal keymap;
-    } events;
+        CSignalT<>                           destroy;
+        CSignalT<IKeyboard::SKeyEvent>       key;
+        CSignalT<IKeyboard::SModifiersEvent> modifiers;
+        CSignalT<IKeyboard::SKeymapEvent>    keymap;
+    } m_events;
 
     bool        good();
     wl_client*  client();
 
-    std::string name = "";
+    std::string m_name = "";
 
   private:
-    SP<CZwpVirtualKeyboardV1> resource;
+    SP<CZwpVirtualKeyboardV1> m_resource;
 
     void                      releasePressed();
+    void                      destroy();
 
-    bool                      hasKeymap = false;
+    bool                      m_hasKeymap = false;
 
-    std::vector<uint32_t>     pressed;
+    std::vector<uint32_t>     m_pressed;
 };
 
 class CVirtualKeyboardProtocol : public IWaylandProtocol {
@@ -41,8 +44,8 @@ class CVirtualKeyboardProtocol : public IWaylandProtocol {
     virtual void bindManager(wl_client* client, void* data, uint32_t ver, uint32_t id);
 
     struct {
-        CSignal newKeyboard; // SP<CVirtualKeyboard>
-    } events;
+        CSignalT<SP<CVirtualKeyboardV1Resource>> newKeyboard;
+    } m_events;
 
   private:
     void onManagerResourceDestroy(wl_resource* res);
@@ -50,8 +53,8 @@ class CVirtualKeyboardProtocol : public IWaylandProtocol {
     void onCreateKeeb(CZwpVirtualKeyboardManagerV1* pMgr, wl_resource* seat, uint32_t id);
 
     //
-    std::vector<UP<CZwpVirtualKeyboardManagerV1>> m_vManagers;
-    std::vector<SP<CVirtualKeyboardV1Resource>>   m_vKeyboards;
+    std::vector<UP<CZwpVirtualKeyboardManagerV1>> m_managers;
+    std::vector<SP<CVirtualKeyboardV1Resource>>   m_keyboards;
 
     friend class CVirtualKeyboardV1Resource;
 };
